pub struct CapabilityManifest {
pub context: String,
pub type_: String,
pub name: String,
pub description: String,
pub capabilities: Vec<CapabilityEntry>,
}Expand description
JSON-LD capability manifest describing what a site offers to agents.
The @context field is always "https://schema.org" and @type is "WebAPI".
Fields
context: Stringtype_: Stringname: Stringdescription: Stringcapabilities: Vec<CapabilityEntry>Trait Implementations
Sourceimpl Clone for CapabilityManifest
impl Clone for CapabilityManifest
Sourcefn clone(&self) -> CapabilityManifest
fn clone(&self) -> CapabilityManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapabilityManifest
impl Debug for CapabilityManifest
Sourceimpl<'de> Deserialize<'de> for CapabilityManifest
impl<'de> Deserialize<'de> for CapabilityManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CapabilityManifest
impl PartialEq for CapabilityManifest
Sourcefn eq(&self, other: &CapabilityManifest) -> bool
fn eq(&self, other: &CapabilityManifest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CapabilityManifest
impl Serialize for CapabilityManifest
impl StructuralPartialEq for CapabilityManifest